==> rsuite-5.62.0.tgz: package/esm/Placeholder/PlaceholderGrid.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject;
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { useClassNames } from "../internals/hooks";
/**
 * The `Placeholder.Grid` component is used to display the loading state of the block.
 * @see https://rsuitejs.com/components/placeholder
 */
var PlaceholderGrid = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    className = props.className,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'placeholder' : _props$classPrefix,
    _props$rows = props.rows,
    rows = _props$rows === void 0 ? 5 : _props$rows,
    _props$columns = props.columns,
    columns = _props$columns === void 0 ? 5 : _props$columns,
    _props$rowHeight = props.rowHeight,
    rowHeight = _props$rowHeight === void 0 ? 10 : _props$rowHeight,
    _props$rowMargin = props.rowMargin,
    rowMargin = _props$rowMargin === void 0 ? 20 : _props$rowMargin,
    _props$rowSpacing = props.rowSpacing,
    rowSpacing = _props$rowSpacing === void 0 ? rowMargin : _props$rowSpacing,
    active = props.active,
    rest = _objectWithoutPropertiesLoose(props, ["as", "className", "classPrefix", "rows", "columns", "rowHeight", "rowMargin", "rowSpacing", "active"]);
  var _useClassNames = useClassNames(classPrefix),
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix,
    withClassPrefix = _useClassNames.withClassPrefix;
  var classes = merge(className, withClassPrefix('grid', {
    active: active
  }));
  var colItems = [];
  for (var i = 0; i < columns; i++) {
    var rowItems = [];
    for (var j = 0; j < rows; j++) {
      rowItems.push( /*#__PURE__*/React.createElement("div", {
        key: j,
        style: {
          height: rowHeight,
          marginTop: j > 0 ? rowSpacing : undefined
        },
        className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["row"])))
      }));
    }
    colItems.push( /*#__PURE__*/React.createElement("div", {
      key: i,
      className: classNames(prefix('grid-col'))
    }, rowItems));
  }
  return /*#__PURE__*/React.createElement(Component, _extends({}, rest, {
    ref: ref,
    className: classes
  }), colItems);
});
PlaceholderGrid.displayName = 'PlaceholderGrid';
PlaceholderGrid.propTypes = {
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  rows: PropTypes.number,
  columns: PropTypes.number,
  rowHeight: PropTypes.number,
  rowSpacing: PropTypes.number,
  active: PropTypes.bool
};
export default PlaceholderGrid;

==> rsuite-5.63.0.tgz: package/esm/Placeholder/PlaceholderGrid.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject;
var _excluded = ["as", "className", "classPrefix", "rows", "columns", "rowHeight", "rowMargin", "rowSpacing", "active"];
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { useClassNames } from "../internals/hooks/index.js";
/**
 * The `Placeholder.Grid` component is used to display the loading state of the block.
 * @see https://rsuitejs.com/components/placeholder
 */
var PlaceholderGrid = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    className = props.className,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'placeholder' : _props$classPrefix,
    _props$rows = props.rows,
    rows = _props$rows === void 0 ? 5 : _props$rows,
    _props$columns = props.columns,
    columns = _props$columns === void 0 ? 5 : _props$columns,
    _props$rowHeight = props.rowHeight,
    rowHeight = _props$rowHeight === void 0 ? 10 : _props$rowHeight,
    _props$rowMargin = props.rowMargin,
    rowMargin = _props$rowMargin === void 0 ? 20 : _props$rowMargin,
    _props$rowSpacing = props.rowSpacing,
    rowSpacing = _props$rowSpacing === void 0 ? rowMargin : _props$rowSpacing,
    active = props.active,
    rest = _objectWithoutPropertiesLoose(props, _excluded);
  var _useClassNames = useClassNames(classPrefix),
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix,
    withClassPrefix = _useClassNames.withClassPrefix;
  var classes = merge(className, withClassPrefix('grid', {
    active: active
  }));
  var colItems = [];
  for (var i = 0; i < columns; i++) {
    var rowItems = [];
    for (var j = 0; j < rows; j++) {
      rowItems.push( /*#__PURE__*/React.createElement("div", {
        key: j,
        style: {
          height: rowHeight,
          marginTop: j > 0 ? rowSpacing : undefined
        },
        className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["row"])))
      }));
    }
    colItems.push( /*#__PURE__*/React.createElement("div", {
      key: i,
      className: classNames(prefix('grid-col'))
    }, rowItems));
  }
  return /*#__PURE__*/React.createElement(Component, _extends({}, rest, {
    ref: ref,
    className: classes
  }), colItems);
});
PlaceholderGrid.displayName = 'PlaceholderGrid';
PlaceholderGrid.propTypes = {
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  rows: PropTypes.number,
  columns: PropTypes.number,
  rowHeight: PropTypes.number,
  rowSpacing: PropTypes.number,
  active: PropTypes.bool
};
export default PlaceholderGrid;
